From: Zooko O'Whielacronx <zooko@zooko.com>
Date: Thu, 5 Feb 2009 16:29:23 +0000 (-0700)
Subject: setup: require new bundled setuptools-0.6c12dev
X-Git-Tag: allmydata-tahoe-1.3.0~78
X-Git-Url: https://git.rkrishnan.org/%5B/%5D%20/uri/frontends/%22news.html?a=commitdiff_plain;h=9ce226b4d837e7dbfe5905d287fb75416f000cc8;p=tahoe-lafs%2Ftahoe-lafs.git

setup: require new bundled setuptools-0.6c12dev
---

diff --git a/ez_setup.py b/ez_setup.py
index 131f72c4..f09fd0fc 100644
--- a/ez_setup.py
+++ b/ez_setup.py
@@ -14,12 +14,12 @@ the appropriate options to ``use_setuptools()``.
 This file can also be run as a script to install or upgrade setuptools.
 """
 import os, sys
-DEFAULT_VERSION = "0.6c11dev"
+DEFAULT_VERSION = "0.6c12dev"
 DEFAULT_DIR     = "misc/dependencies/"
 DEFAULT_URL     = "file:"+DEFAULT_DIR
 
 md5_data = {
-    'setuptools-0.6c11dev.egg': '9734e821d3388af78fceecb264b3e854',
+    'setuptools-0.6c12dev.egg': '770da1c9e5446cf04273f0f1cdb8c09a',
 }
 
 import sys, os
@@ -39,7 +39,7 @@ def _validate_md5(egg_name, data):
 
 def use_setuptools(
     version=DEFAULT_VERSION, download_base=DEFAULT_URL, to_dir=os.curdir,
-    min_version="0.6c11dev", download_delay=15
+    min_version="0.6c12dev", download_delay=15
 ):
     """Automatically find/download setuptools and make it available on sys.path
 
diff --git a/setup.py b/setup.py
index 6553c834..7183b684 100644
--- a/setup.py
+++ b/setup.py
@@ -28,11 +28,11 @@ except ImportError:
     pass
 else:
     # This invokes our own customized version of ez_setup.py to make sure that setuptools
     # v0.6c11dev (which is our own toothpick of setuptools) is used to build.  Note that we can
     # use any version of setuptools >= 0.6c6 to *run* -- see _auto_deps.py for run-time
     # dependencies (a.k.a. "install_requires") -- this is only for build-time dependencies
     # (a.k.a. "setup_requires").
-    use_setuptools(download_delay=0, min_version="0.6c11dev")
+    use_setuptools(download_delay=0, min_version="0.6c12dev")
 
 from setuptools import find_packages, setup
 from setuptools.command import sdist
@@ -28,11 +28,11 @@ except ImportError:
 else:
     # This invokes our own customized version of ez_setup.py to make sure that setuptools
-    # v0.6c11dev (which is our own toothpick of setuptools) is used to build.  Note that we can
+    # v0.6c12dev (which is our own toothpick of setuptools) is used to build.  Note that we can
     # use any version of setuptools >= 0.6c6 to *run* -- see _auto_deps.py for run-time
     # dependencies (a.k.a. "install_requires") -- this is only for build-time dependencies